@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import contextlib
 import copy
 import io
@@ -6,8 +8,8 @@ import re
 import sys
 import textwrap
 import unittest
-from typing import Any, Dict
-from unittest.mock import patch
+from typing import Any
+from unittest import mock
 
 import mkdocs
 from mkdocs.config import base
@@ -34,8 +36,8 @@ class TestCase(unittest.TestCase):
     def get_config(
         self,
         schema: type,
-        cfg: Dict[str, Any],
-        warnings: Dict[str, str] = {},
+        cfg: dict[str, Any],
+        warnings: dict[str, str] = {},
         config_file_path=None,
     ):
         config = base.LegacyConfig(base.get_schema(schema), config_file_path=config_file_path)
@@ -349,6 +351,28 @@ class IpAddressTest(TestCase):
         self.assertEqual(conf['option'].host, '127.0.0.1')
         self.assertEqual(conf['option'].port, 8000)
 
+    def test_bind_all_IPv4_address(self):
+        addr = '0.0.0.0:8000'
+
+        class Schema:
+            option = c.IpAddress(default=addr)
+
+        conf = self.get_config(Schema, {'option': None})
+        self.assertEqual(str(conf['option']), addr)
+        self.assertEqual(conf['option'].host, '0.0.0.0')
+        self.assertEqual(conf['option'].port, 8000)
+
+    def test_bind_all_IPv6_address(self):
+        addr = ':::8000'
+
+        class Schema:
+            option = c.IpAddress(default=addr)
+
+        conf = self.get_config(Schema, {'option': None})
+        self.assertEqual(str(conf['option']), addr)
+        self.assertEqual(conf['option'].host, '::')
+        self.assertEqual(conf['option'].port, 8000)
+
     @unittest.skipIf(
         sys.version_info < (3, 9, 5),
         "Leading zeros allowed in IP addresses before Python3.9.5",
@@ -379,37 +403,6 @@ class IpAddressTest(TestCase):
         with self.expect_error(option="Must be a string of format 'IP:PORT'"):
             self.get_config(self.Schema, {'option': '127.0.0.1'})
 
-    def test_unsupported_address(self):
-        class Schema:
-            dev_addr = c.IpAddress()
-
-        self.get_config(
-            Schema,
-            {'dev_addr': '0.0.0.0:8000'},
-            warnings=dict(
-                dev_addr="The use of the IP address '0.0.0.0' suggests a production "
-                "environment or the use of a proxy to connect to the MkDocs "
-                "server. However, the MkDocs' server is intended for local "
-                "development purposes only. Please use a third party "
-                "production-ready server instead."
-            ),
-        )
-
-    def test_unsupported_IPv6_address(self):
-        class Schema:
-            dev_addr = c.IpAddress()
-
-        self.get_config(
-            Schema,
-            {'dev_addr': ':::8000'},
-            warnings=dict(
-                dev_addr="The use of the IP address '::' suggests a production environment "
-                "or the use of a proxy to connect to the MkDocs server. However, "
-                "the MkDocs' server is intended for local development purposes "
-                "only. Please use a third party production-ready server instead."
-            ),
-        )
-
 
 class URLTest(TestCase):
     def test_valid_url(self):
@@ -899,7 +892,6 @@ class SiteDirTest(TestCase):
 
     def test_common_prefix(self):
         """Legitimate settings with common prefixes should not fail validation."""
-
         test_configs = (
             {'docs_dir': 'docs', 'site_dir': 'docs-site'},
             {'docs_dir': 'site-docs', 'site_dir': 'site'},
@@ -1112,8 +1104,8 @@ class NavTest(TestCase):
             - Home: index.md
             - getting-started.md
             - User Guide:
-                - Overview: user-guide/index.md
-                - Installation: user-guide/installation.md
+              - Overview: user-guide/index.md
+              - Installation: user-guide/installation.md
             '''
         )
         nav = yaml_load(io.StringIO(nav_yaml))
@@ -1191,14 +1183,14 @@ class SubConfigTest(TestCase):
             with self.subTest(val):
                 with self.expect_error(
                     option=re.compile(
-                        r"The configuration is invalid. The expected type was a key value mapping "
-                        r"\(a python dict\) but we got an object of type: .+"
+                        r"The configuration is invalid. Expected a key-value mapping "
+                        r"\(dict\) but received: .+"
                     )
                 ):
                     self.get_config(Schema, {'option': val})
 
     def test_subconfig_ignored(self):
-        """Default behaviour of subconfig: validation is ignored"""
+        """Default behaviour of subconfig: validation is ignored."""
 
         # Nominal
         class Schema1:
@@ -1260,6 +1252,22 @@ class SubConfigTest(TestCase):
         conf = self.get_config(Schema, {'option': {'cc': 'foo'}})
         self.assertEqual(conf['option'], {'cc': 'foo'})
 
+    def test_config_file_path_pass_through(self):
+        """Necessary to ensure FilesystemObject validates the correct path."""
+        passed_config_path = None
+
+        class SubType(c.BaseConfigOption):
+            def pre_validation(self, config, key_name):
+                nonlocal passed_config_path
+                passed_config_path = config.config_file_path
+
+        class Schema:
+            sub = c.SubConfig(('opt', SubType()))
+
+        config_path = "foo/mkdocs.yaml"
+        self.get_config(Schema, {"sub": {"opt": "bar"}}, config_file_path=config_path)
+        self.assertEqual(passed_config_path, config_path)
+
 
 class ConfigItemsTest(TestCase):
     def test_subconfig_with_multiple_items(self):
@@ -1340,15 +1348,15 @@ class ConfigItemsTest(TestCase):
             conf = self.get_config(Schema, {'sub': [{'opt': 'z'}, {'opt': 2}]})
 
         with self.expect_error(
-            sub="The configuration is invalid. The expected type was a key value mapping "
-            "(a python dict) but we got an object of type: <class 'int'>"
+            sub="The configuration is invalid. Expected a key-value mapping "
+            "(dict) but received: <class 'int'>"
         ):
             conf = self.get_config(Schema, {'sub': [1, 2]})
 
 
 class MarkdownExtensionsTest(TestCase):
-    @patch('markdown.Markdown')
-    def test_simple_list(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_simple_list(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
             mdx_configs = c.Private()
@@ -1360,8 +1368,8 @@ class MarkdownExtensionsTest(TestCase):
         self.assertEqual(conf['markdown_extensions'], ['foo', 'bar'])
         self.assertEqual(conf['mdx_configs'], {})
 
-    @patch('markdown.Markdown')
-    def test_list_dicts(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_list_dicts(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
             mdx_configs = c.Private()
@@ -1383,8 +1391,8 @@ class MarkdownExtensionsTest(TestCase):
             },
         )
 
-    @patch('markdown.Markdown')
-    def test_mixed_list(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_mixed_list(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
             mdx_configs = c.Private()
@@ -1404,8 +1412,8 @@ class MarkdownExtensionsTest(TestCase):
             },
         )
 
-    @patch('markdown.Markdown')
-    def test_dict_of_dicts(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_dict_of_dicts(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
             mdx_configs = c.Private()
@@ -1427,8 +1435,8 @@ class MarkdownExtensionsTest(TestCase):
             },
         )
 
-    @patch('markdown.Markdown')
-    def test_builtins(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_builtins(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions(builtins=['meta', 'toc'])
             mdx_configs = c.Private()
@@ -1466,8 +1474,8 @@ class MarkdownExtensionsTest(TestCase):
         self.assertEqual(conf['markdown_extensions'], ['meta', 'toc'])
         self.assertEqual(conf['mdx_configs'], {'toc': {'permalink': True}})
 
-    @patch('markdown.Markdown')
-    def test_configkey(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_configkey(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions(configkey='bar')
             bar = c.Private()
@@ -1507,16 +1515,16 @@ class MarkdownExtensionsTest(TestCase):
         self.assertEqual(conf['markdown_extensions'], [])
         self.assertEqual(conf['mdx_configs'], {})
 
-    @patch('markdown.Markdown')
-    def test_not_list(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_not_list(self):
         class Schema:
             option = c.MarkdownExtensions()
 
         with self.expect_error(option="Invalid Markdown Extensions configuration"):
             self.get_config(Schema, {'option': 'not a list'})
 
-    @patch('markdown.Markdown')
-    def test_invalid_config_option(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_invalid_config_option(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
 
@@ -1530,8 +1538,8 @@ class MarkdownExtensionsTest(TestCase):
         ):
             self.get_config(Schema, config)
 
-    @patch('markdown.Markdown')
-    def test_invalid_config_item(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_invalid_config_item(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
 
@@ -1543,8 +1551,8 @@ class MarkdownExtensionsTest(TestCase):
         with self.expect_error(markdown_extensions="Invalid Markdown Extensions configuration"):
             self.get_config(Schema, config)
 
-    @patch('markdown.Markdown')
-    def test_invalid_dict_item(self, mock_md):
+    @mock.patch('markdown.Markdown', mock.Mock())
+    def test_invalid_dict_item(self):
         class Schema:
             markdown_extensions = c.MarkdownExtensions()
 
